import React, { useState } from 'react';
import { Button, Modal, Form } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import { getOrderList } from '@/services/order';
import { getevaluation } from '@/services/eval'

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm:ss') : '';
};
const FormItem = Form.Item;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };

export default (props) => {
  const [show, setShow] = useState(false)
  const [evaluation, setEval] = useState()
  const getEvaluated = (val) => {
    getevaluation(val).then(res => {
      setEval(res)
      setShow(true)
    })
  }
  const columns = [
    {
      title: '机构名',
      dataIndex: 'orgName',
      key: 'orgName',
    },
    {
      title: '农机名',
      dataIndex: 'machineryName',
      key: 'machineryName',
    },
    {
      title: '农机型号',
      dataIndex: 'typeName',
      key: 'typeName',
    },
    {
      title: '需求时间',
      dataIndex: 'appointmentDate',
      key: 'appointmentDate',
    },
    {
      title: '作业面积',
      dataIndex: 'amount',
      key: 'amount',
      search: false,
    },
    {
      title: '费用',
      dataIndex: 'charges',
      key: 'charges',
      render: (t) => t / 100,
      search: false
    },
    {
      title: '下单时间',
      dataIndex: 'createDate',
      key: 'createDate',
      search: false,
      render: (t) => formatterTime(t),
      width: 200,
    },
    {
      title: '评价状态',
      dataIndex: 'isEvaluated',
      key: 'isEvaluated',
      valueType: 'select',
      valueEnum: {
        '': { text: '不限', status: 'Default' },
        0: { text: '待评价' },
        1: { text: '已评价' }
      },
    },
    {
      title: '操作',
      valueType: 'option',
      render: (_, record) => record.isEvaluated ? [
        <Button
          style={{ padding: 0 }}
          type="link"
          key={1}
          onClick={() => getEvaluated(record.orderId)}
        >
          查看评价
        </Button>
      ] : '',
    },
    //操作如果是需求多台机器则需调度 状态为待确认时 状态栏显示调度按钮跳到调度页面
    // 如果是申请退款 则出现处理按钮 显示需求时间 如果未到则退款并且改变已分配农机手状态和农机状态
    // 如果已经服务过了 则可以打电话给农户咨询具体情况看是否退部分款项
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        request={getOrderList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="orderId"
        options={false}
        scroll={{ x: 1000 }}
      />
      <Modal
        forceRender
        title='评价'
        visible={show}
        onCancel={() => setShow(false)}
        keyboard={false}
        maskClosable={false}
        destroyOnClose={true}
        footer={null}
      >
        <Form {...formItemLayout}>
          <FormItem label="下单人" >{evaluation?.personName}</FormItem>
          <FormItem label="评分" >{evaluation?.score}</FormItem>
          <FormItem label="评价内容" >{evaluation?.content}</FormItem>
        </Form>
      </Modal>

    </PageHeaderWrapper>
  );
};
